@@ -2,13 +2,12 @@ from copy import deepcopy
 
 from basicsr.utils import get_root_logger
 from basicsr.utils.registry import LOSS_REGISTRY
-from .losses import (CharbonnierLoss, GANLoss, L1Loss, MSELoss, PerceptualLoss,
-                     WeightedTVLoss, g_path_regularize, gradient_penalty_loss,
-                     r1_penalty)
+from .losses import (CharbonnierLoss, GANLoss, L1Loss, MSELoss, PerceptualLoss, WeightedTVLoss, g_path_regularize,
+                     gradient_penalty_loss, r1_penalty)
 
 __all__ = [
-    'L1Loss', 'MSELoss', 'CharbonnierLoss', 'WeightedTVLoss', 'PerceptualLoss',
-    'GANLoss', 'gradient_penalty_loss', 'r1_penalty', 'g_path_regularize'
+    'L1Loss', 'MSELoss', 'CharbonnierLoss', 'WeightedTVLoss', 'PerceptualLoss', 'GANLoss', 'gradient_penalty_loss',
+    'r1_penalty', 'g_path_regularize'
 ]
 
 
@@ -16,7 +15,7 @@ def build_loss(opt):
     """Build loss from options.
 
     Args:
-        opt (dict): Configuration. It must constain:
+        opt (dict): Configuration. It must contain:
             type (str): Model type.
     """
     opt = deepcopy(opt)
